schema_field_names

Function schema_field_names 

pub fn schema_field_names() -> Vec<&'static str>
Ordered list of column names for the resources schema.

Used by the golden-test harness and by tfparser schema to dump the schema for downstream tools without round-tripping through Arrow.