pub struct LineCol {
pub line: u32,
pub column: u32,
}Expand description
1-based (line, column) position in a source file.
column is in bytes, matching the rest of the IR’s byte-offset
convention. Multi-byte UTF-8 characters straddling a column boundary
will appear as a column at their starting byte.
Fields
line: u321-based line number.
column: u321-based byte column within that line.