#[non_exhaustive]pub enum ProviderError {
Io {
path: PathBuf,
source: Error,
},
FileTooLarge {
path: PathBuf,
observed: u64,
limit: u64,
},
Ini {
path: PathBuf,
source: ParseError,
},
Yaml {
path: PathBuf,
source: Error,
},
Validation {
path: PathBuf,
source: ValidationErrors,
},
InvalidEntry {
profile: Arc<str>,
source: ValidationError,
},
ChainTooLong {
profile: Arc<str>,
limit: usize,
},
StrictUnresolved {
count: usize,
first: Arc<str>,
},
}Expand description
Errors raised by the provider-resolver layer.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Io
I/O failure reading ~/.aws/config or a profile-map YAML file.
FileTooLarge
The configured profile-map file exceeded the size cap.
Ini
INI parse error (~/.aws/config).
Yaml
YAML deserialise error.
Validation
validator rejected a field in the profile-map YAML.
Fields

source: ValidationErrorsAggregated validation errors.
InvalidEntry
An entry passed validator but failed our newtype check
(account-id / region length-charset). Carries the offending
profile name so the operator can fix the YAML.
ChainTooLong
source_profile chain exceeded the hop cap (8 per spec  3.1).
Fields
StrictUnresolved
Resolver was configured in strict mode and one or more profiles
referenced from a Workspace had no entry in the profile map.